import {html, TemplateResult} from 'lit';
import {customElement} from 'lit/decorators.js';
import {repeat} from 'lit/directives/repeat.js';
import BaseFacetElement from '../BaseFacetElement';

/**
 * A facet button element.
 */
@customElement('facet-button')
export class FacetButton extends BaseFacetElement {
  /**
   * Returns the html for the facet's options.
   */
  _getOptions(): TemplateResult {
    const facet = this._getFacetData();

    return html`
      <ul>
        ${repeat(
          facet.results,
          (value) => value.key,
          (value) => {
            return html`
              <li class="facet button ${value.active ? 'selected' : ''}">
                <button
                  class="${this.key}"
                  type="button"
                  name="${value.key}"
                  value="${value.key}"
                  aria-pressed="${value.active ?? false}"
                  @click=${() => this.applyFacet(this.urlAlias, value.key)}
                >${value.label}${this.showCount ? ` (${value.count})` : null}
              </li>
            `;
          }
        )}
      </ul>
    `;
  }

  override render() {
    super.render();

    if (!this.shouldRender()) {
      return null;
    }

    if (this.collapsible) {
      return this.wrapCollapsible(
        this._getCollapsibleLabelElement(),
        html`${this._getOptions()} ${this._getResetElement()}`
      );
    }

    return html`
      ${this.showLabel ? this._getLabelElement() : null} ${this._getOptions()}
      ${this._getResetElement()}
    `;
  }
}

declare global {
  interface HTMLElementTagNameMap {
    'facet-button': FacetButton;
  }
}
