<?php

namespace Drupal\search_web_components_facets\EventSubscriber;

use Drupal\Component\Plugin\Factory\FactoryInterface;
use Drupal\facets\FacetManager\DefaultFacetManager;
use Drupal\search_api_decoupled\Event\SearchApiEndpointEvents;
use Drupal\search_api_decoupled\Event\SearchApiEndpointResultsAlter;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Add facet config to the search api endpoint.
 */
class EndpointEventSubscriber implements EventSubscriberInterface {

  /**
   * The facet manager.
   *
   * @var \Drupal\facets\FacetManager\DefaultFacetManager
   */
  protected $facetManager;

  /**
   * The facets query type manager.
   *
   * @var \Drupal\Component\Plugin\Factory\FactoryInterface
   */
  protected $queryTypeManager;

  /**
   * Constructs a new SearchApiEndpointEventSubscriber object.
   *
   * @param \Drupal\facets\FacetManager\DefaultFacetManager $facet_manager
   *   The facets manager.
   * @param \Drupal\Component\Plugin\Factory\FactoryInterface $query_type_manager
   *   The query type manager.
   */
  public function __construct(DefaultFacetManager $facet_manager, FactoryInterface $query_type_manager) {
    $this->facetManager = $facet_manager;
    $this->queryTypeManager = $query_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      SearchApiEndpointEvents::SEARCH_RESULTS_ALTER => 'onSearchResultsAlter',
    ];
  }

  /**
   * Change search result response.
   *
   * @param \Drupal\search_api_decoupled\Event\SearchApiEndpointResultsAlter $event
   *   The event.
   */
  public function onSearchResultsAlter(SearchApiEndpointResultsAlter $event) {
    $search_response = $event->getResponse();
    $search_api_endpoint = $event->getSearchApiEndpoint();
    $facets = $this->facetManager->getFacetsByFacetSourceId('search_api:search_api_endpoint__' . $search_api_endpoint->id());

    foreach ($search_response['facets'] as &$facet) {
      $id = $facet['key'];

      $config = NULL;

      foreach ($facets as $f) {
        if ($id === $f->id()) {
          $config = $f;
          break;
        }
      }

      if (!$config) {
        continue;
      }

      $include = [
        'widget',
        'show_title',
        'empty_behavior',
        'url_alias',
        'show_only_one_result',
        'hard_limit',
        'missing',
        'missing_label',
      ];

      foreach ($include as $key) {
        if ($key === 'widget') {
          $facet['settings'][$key] = $config->get($key)['config'];
        }
        else {
          $facet['settings'][$key] = $config->get($key);
        }
      }
    }

    $event->setResponse($search_response);
  }

}
